 #ifndef COMMUNICATION_INTERFACES_H
#define COMMUNICATION_INTERFACES_H

	/**
	* This file describes describes which communication interfaces are available.  
	* 
	* Each interface has a unique name. Using the neighbor repository, it is possible to specify
	* for each neighboring node which radio interface should be used to transmit packets. 
	* The preferred radio interface can be set  for each neighboring node using
	* the neighbor table.
	*
	* Example: to use the USB radio when sending a packet to next_hop adress 100:
	* uint8_t preferedRadio = USB;
	* call NeighborRepository.setParameter(100, RADIO_INTERFACE, sizeof(preferedRadio ), (void*) &preferedRadio);
	* 
	* If nothing is specified, the default communication interface is used.
	*
	**/


	/**
	* Step 1
	* -------
	* Add the name and ID of new communication interfaces
	**/
	#ifdef RADIO_TYPE_SETTINGS
		enum{
			NO_RADIO = 1, 			// The packet will be dropped
			RADIO_CC2420 = 2,		// Send the resulting packet over the CC2420 radio interface
			USB = 3,			// Send the resulting packet over the USB interface
			ALL_INTERFACES = 4,	// Send a packet over all existing interfaces
		};
	#endif



	/**
	* Step 2
	* -------
	* Specify the default radio interface
	**/
	#ifdef RADIO_TYPE_SETTINGS
		enum{
			DEFAULT_RADIO_INTERFACE = RADIO_CC2420, 
		};
	#endif



	/**
	* Step 3
	* -------
	* Make sure that the each radio controller can be located
	**/
	#ifdef PACKET_PART_WIRING	

		#if TOSSIM==1
			components Radio_CC2420_Simulator_C;
			RadioInterfaceP.RadioInterface -> Radio_CC2420_Simulator_C;
		#elif OPTIMIZED_CC2420_RADIO==1
			components RadioController_CC2420_HALC as RadioController_CC2420;
			RadioInterfaceP.RadioInterface -> RadioController_CC2420;
		#else
			components RadioController_CC2420_C as RadioController_CC2420;
			RadioInterfaceP.RadioInterface -> RadioController_CC2420;
		#endif


		// USB radio controller (disabled by default)
		//components RadioController_USB_C;
		//RadioInterfaceP.RadioInterface -> RadioController_USB_C;

	#endif
	



#endif

        
