/*
* Copyright (C) Ghent University - IBBT. All rights reserved.
*
* "This file is part of the IDRA framework (http://idraproject.net)
*
* IDRA is an open-source framework, developed for easy integration and 
* efficient combination of network protocols for netwerked embedded systems.
*   
* IDRA is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 2 of the License, or
* (at your option) any later version.
*
* IDRA is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with IDRA.  If not, see <http://www.gnu.org/licenses/>."
*/


// Adding new modules to the Information Driven Architecture

/**
* Step 1
* -------
* First, the configurations of the required modules are listed.
* All modules written here will be included in
* the final binary file.
*
**/


// Filtering
components LinkLevelDuplicateDetection_C;
components PacketTypeFiltering_C;

// MAC
components MAC_Simple_C;
//components MAC_SMAC_C;
//components MAC_LPL_C;

// Routing
//components Routing_Collection_RegularNode_C;
//components Routing_Collection_SinkNode_C;
components Routing_AODV_C;
//components Routing_DYMO_C;
//components Routing_Broadcast_C;

// Monitoring
//components Monitoring_NeighborEnergy_C;
//components Monitoring_NeighborRole_C;

// Applications
components ApplicationPacketGenerator_C;



/**
* Step 2
* -------
* Afterwards, the required modules are wired to the system. 
**/

// Filtering
MultiModeManagerP.Module -> LinkLevelDuplicateDetection_C;
MultiModeManagerP.Module-> PacketTypeFiltering_C;

// MAC
MultiModeManagerP.Module -> MAC_Simple_C;
//MultiModeManagerP.Module -> MAC_SMAC_C;
//MultiModeManagerP.Module -> MAC_LPL_C;

// routing
//MultiModeManagerP.Module -> Routing_Collection_RegularNode_C;
//MultiModeManagerP.Module -> Routing_Collection_SinkNode_C;
MultiModeManagerP.Module -> Routing_AODV_C;
//MultiModeManagerP.Module -> Routing_DYMO_C;
//MultiModeManagerP.Module -> Routing_Broadcast_C;

// Monitoring
//MultiModeManagerP.Module -> Monitoring_NeighborEnergy_C;
//MultiModeManagerP.Module -> Monitoring_NeighborRole_C;

// Applications
MultiModeManagerP.Module -> ApplicationPacketGenerator_C;




/**
* Step 3
* -------
*
* Type 'make telosb' in any tinyos2.1 environment to have a 
* working binary file. 
*
**/