/*
* Copyright (C) Ghent University - IBBT. All rights reserved.
*
* "This file is part of the IDRA framework (http://idraproject.net)
*
* IDRA is an open-source framework, developed for easy integration and 
* efficient combination of network protocols for netwerked embedded systems.
*   
* IDRA is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 2 of the License, or
* (at your option) any later version.
*
* IDRA is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with IDRA.  If not, see <http://www.gnu.org/licenses/>."
*/

#ifndef CONFIGURATION_H
#define CONFIGURATION_H


/***********************************
* enable or disable printf statements 
* with errors or warnings from the system
* (enabling printf statements in individual 
* protocols is done in the header of the relevant protocols)
***********************************/
//#define SYSTEM_PRINTF



/***********************************
* Settings for the LEDS
* If enabled, the HAL will activate the leds: 
* -red when sending a packet
* -green when receiving a packet
* -blue when the radio is awake
***********************************/
#define RADIO_LEDS


/***********************************
* Enable or disable system wide aggregation
* of information parameters
* Enabling this setting increases processing 
* and memory overhead, but reduces the packet transmissions
***********************************/
//#define ENABLE_AGGREGATION


/***********************************
* Enable or disable system packet conversion.
* When this is enabled, packets are automatically
* converted to other packet types, hop per hop.
***********************************/
#define PACKET_CONVERSION


/***********************************
* Use an optimized CC2420 radio implementation
* which is faster and has more options
* (This is enabled by default)
***********************************/
// see makefile


/***********************************
* Increase the tmotesky clock frequency to 8 MHz,
* rather than the default 2 MHz 
* (This is disabled by default)
***********************************/
// see makefile


/***********************************
* enable or disable the wilab visualizer
***********************************/
//#define WILAB_VISUALIZER


/***********************************
* Initial transmit power (from min to max: 1 to 31)
* (can afterwards still be changed by the protocols)
***********************************/
// see makefile


/***********************************
* Select the QoS policies that should be used.
* (if SIMPLE_QOS is disabled, more advanced QoS policies
* are used, that give better QoS support but require
* more CPU and packet overhead)
***********************************/
#define SIMPLE_QOS


/***********************************
* Configurable system variables
***********************************/
enum {

	/***********************************
	* Settings for the shared queue
	***********************************/

	MAXPACKETSIZE = 114,			// in bytes
	MAXMETADATASIZE = 33,	//This is to large for metadata, but it makes sure that the maximal packetsize (127) can still be stored in the sharedqueue
	QUEUESIZE = 6,				// number of entries in the shared packet queue
	MAXPACKETPARAMETERS = 12,		// max number of parameters that are associated with a packet


	/***********************************
	* Multi-mode manager settings
	***********************************/

	MAXFILTERS = 20,			// max number of filters that can be added to the MMM
	RANDOM_STARTUP_DELAY = 5000,		// Max random delay before the node starts-up

	/***********************************
	* Max number of parameters in the parameter exchange
	***********************************/
  
	MAXEXCHANGEPARAMETERS = 5,
	MAXPARAMETERSIZE = 85,		// in bytes
	TIMEBETWEENCHECKS = 80,  		// in msec. lower = more processing overhead, but more probability that parameters can be combined


	/***********************************
	* Settings for the cross-layer data repository
	***********************************/

	// Parameter repository
	PARAMETER_MEMORY = 200,		// in bytes

	// Neighbor repository
	MAXNUMBEROFNEIGHBOURS = 15,
	MAX_PARAM=5,
	AVERAGE_PARAM_SIZE=2,			// in bytes

	// QoS Repository (not used when simple qos is selected)
	MAXNUMBEROFINFORMATIONPARAMETERS = 6,
	MAX_QOS_PARAM=4,
	AVERAGE_QOS_PARAM_SIZE = 4, 	// in bytes

	/***********************************
	* Settings for the HAL
	***********************************/

	IDRA_AM_ADDR = 112,			// tinyos active_message address
	
};

#endif

