#ifndef HALTYPES
#define HALTYPES
enum {
  //Default Receive radio settings
  DEFAULT_CHANNEL = 26,
  DEFAULT_FREQUENCY = (DEFAULT_CHANNEL - 11)* 5 + 2405, //= 2480 = channel 26
  DEFAULT_SHORTADDRESS = 0xFFFF,
  DEFAULT_PANID = 0xFFFF,
  //Default transmit radio settings
  DEFAULT_TRANSMITPOWER = 0, //in dBm
  DEFAULT_CCAMODE = 3,
  DEFAULT_NUMBEROFCCA = 1,
  
  MAX_PACKET_LENGTH = 127, //Has to be ODD (allignment problem workaround)
  
  #ifndef MAX_NUMBER_OF_PARTS_IN_A_PACKET
  MAX_NUMBER_OF_PARTS_IN_A_CC2420_PACKET = 10,
  #endif
  //RadioRfEnergy defaults
  RFENERGY_FREQ_STEPTIME = 1000, //binary milliseconds
  RFENERGY_INTERSAMPLEDELAY = 1000, //binary microseconds
  RFENERGY_CLASS_WIDTH = 1,
  RFENERGY_CLASS_REFERENCELEVEL = 105,
  RFENERGY_NUMBER_OF_CLASSES = 45,
};

typedef uint16_t channel_t;
typedef uint32_t time_t;
typedef uint32_t date_t;
typedef uint32_t localtime_t;
typedef nx_uint32_t nx_localtime_t;
typedef int16_t powerlevel_t;

typedef enum {
  OFF = 0, // The complete stack is disabled
  SLEEP = 1, // This is the lowest state of functionality (Radio: register access)
  STANDBY = 2, // This is the middle state of functionality (Radio: RAM access)
  AWAKE = 3, //Transmitting or in receive mode
} powerstate_t;

typedef struct {
  localtime_t receiveTime;
  uint16_t frequency;
  int8_t rssi;
  uint8_t linkQuality;
  bool crcOk;
  uint8_t dummy; //in order to get the structure size even
} rxmetadata_t;

typedef struct {
  uint8_t payload[MAX_PACKET_LENGTH];
  uint8_t payloadLength;
  rxmetadata_t rxMetaData;
} rxframe_t;

typedef struct {
  uint8_t length;
  void *packetPart;
} txframe_t;

typedef struct {
  uint16_t frequency;
  localtime_t starttime;
  uint32_t measurementDuration; //in ms
  int16_t min;
  //Avg noise measurements are fixed point (factor 100, or two decimal digits after comma)
  int16_t avg;
  uint32_t sumx_pow2;
  uint16_t numberOfSamples;
  int16_t max;
  int16_t classMin;
  int16_t classWidth;
  uint16_t numberOfClasses;
  // The first class counts everything below the class minimum
  // The second class everything between the class minimum and the second class boundary
  // ...
  // The last class counts everything above the class maximum
  uint16_t classes[RFENERGY_NUMBER_OF_CLASSES];

} rfenergy_t;

// typedef union ieee154_address {
//   // Whether this is a short or extended address
//   // depends on the respective addressing mode
//   uint16_t shortAddress;
//   uint64_t extendedAddress;
// } ieee154_address_t;

#endif


