/*
* Copyright (C) Ghent University - IBBT. All rights reserved.
*
* "This file is part of the IDRA framework (http://idraproject.net)
*
* IDRA is an open-source framework, developed for easy integration and 
* efficient combination of network protocols for netwerked embedded systems.
*   
* IDRA is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 2 of the License, or
* (at your option) any later version.
*
* IDRA is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with IDRA.  If not, see <http://www.gnu.org/licenses/>."
*/

#ifndef FUNCTIONS_H
#define FUNCTIONS_H



/**********************************************************
*  Combine function for fan-outs of modules which return 16 bit values.
***********************************************************/

// combine function for uint16_h = highest combine
// highest of the values
typedef uint16_t uint16_h NESC_COMBINE("hcombine16");
uint16_t hcombine16(uint16_t r1, uint16_t r2) @safe(){
	return r1 < r2 ? r2 : r1;
}

// combine function for uint16_z = lowest combine.
// zero if any zero value is available, otherwise the lowest non-zero value
typedef uint16_t uint16_l NESC_COMBINE("lcombine16");
uint16_t lcombine16(uint16_t r1, uint16_t r2) @safe(){
	return r1 < r2 ? r1 : r2; 
}

// combine function for uint8_h = highest combine
// highest of the values
typedef int8_t int8_h NESC_COMBINE("hcombine8");
int8_t hcombine8(int8_t r1, int8_t r2) @safe(){
	return r1 < r2 ? r2 : r1; 
}

// combine function for error_any
// returns SUCCESS if any result was SUCCESS
typedef error_t error_any NESC_COMBINE("anycombineError");
error_t anycombineError(error_t r1, error_t r2) @safe(){
	if(r1==SUCCESS||r2==SUCCESS) return SUCCESS;
	else return FAIL;
}


/**********************************************************
*  shorter memcpy function which prevents 16 bit alignment problems while copying
***********************************************************/

void * memcpy(void *dst0, const void *src0, size_t len){
	char *dst = (char *)dst0;
	const char *src = (const char *)src0;
	void *ret = dst0;
	if(src0>dst0){
		// normal situation copy from right to left (low address to high address
		for (; len > 0; len--)
			*dst++ = *src++;
	} else {
		// copy from left to right (high address to low address)
		dst= dst + len-1;
		src=src + len-1;
		for (; len > 0; len--)
			*dst-- = *src--;
	}
	return ret;
} 


/**********************************************************
*  shorter memset function which prevents 16 bit alignment problems while copying
***********************************************************/

void * memset(void *dst0, int value, size_t len){
	char *dst = (char *)dst0;
	void *ret = dst0;
	for (; len > 0; len--)
		*dst++ = value;
	return ret;
} 



#endif
